@@ -72,8 +72,6 @@ function timer_methods:set(delay)
 
     w:cancel()
 
-    mt.delay = delay
-
     eco.run(function(...)
         if w:wait(delay) then
             mt.cb(...)
@@ -81,40 +79,47 @@ function timer_methods:set(delay)
     end, self, unpack(mt.arguments))
 end
 
-function timer_methods:start()
-    local mt = getmetatable(self)
-    self:set(mt.delay)
-    return self
-end
-
 --[[
     The at function is used to create a timer that will execute a given callback function after
     a specified delay time.
-    After a timer is created, it will not start automatically. You need to manually execute
-    'start' to activate it.
     The callback function will receive the timer object as its first parameter, and the rest of
     the parameters will be the ones passed to the at function.
 
     To use the at function, you need to provide three parameters:
 
-    delay: The amount of time to wait before executing the callback function, in seconds.
+    delay: Optional the amount of time to wait before executing the callback function, in seconds.
+           If not provide this argument, you must call it's set method to start it.
     cb: The callback function that will be executed after the specified delay time.
     ...: Optional arguments to pass to the callback function.
 
-    The at function returns a timer object with three methods:
+    The at function returns a timer object with two methods:
     set: Sets the timer to execute the callback function after the specified delay time.
     cancel: Cancels the timer so that the callback function will not be executed.
-    start: Starts or resets the timer to execute the callback function again after the same delay time.
 --]]
-function M.at(delay, cb, ...)
+function M.at(...)
+    local arg1, arg2 = select(1, ...)
+    local delay, cb, arguments
+
+    if type(arg1) == 'number' then
+        delay = arg1
+        cb = arg2
+        arguments = { select(3, ...) }
+    else
+        cb = arg1
+        arguments = { select(2, ...) }
+    end
+
+    assert(type(cb) == 'function')
+
     local tmr = setmetatable({}, {
         w = new_timer(),
         cb = cb,
-        delay = delay,
-        arguments = { ... },
+        arguments = arguments,
         __index = timer_methods
     })
 
+    if delay then tmr:set(delay) end
+
     return tmr
 end
 
